built_modules = list(name for name in
    "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;Designer;Xml;Help;Multimedia;MultimediaWidgets;OpenGL;OpenGLWidgets;Positioning;Location;NetworkAuth;Nfc;Qml;Quick;Quick3D;QuickControls2;QuickTest;QuickWidgets;RemoteObjects;Scxml;Sensors;SerialPort;SerialBus;StateMachine;TextToSpeech;Charts;SpatialAudio;Svg;SvgWidgets;DataVisualization;Graphs;GraphsWidgets;Bluetooth;UiTools;AxContainer;WebChannel;WebSockets;HttpServer;3DCore;3DRender;3DInput;3DLogic;3DAnimation;3DExtras"
    .split(";"))

shiboken_library_soversion = str(6.8)
pyside_library_soversion = str(6.8)

version = "6.8.2"
version_info = (6, 8, 2, "", "")

__build_date__ = '2025-02-02T09:17:37+00:00'
__build_commit_date__ = '2025-02-02T08:48:09+00:00'
__build_commit_hash__ = 'de9375cf0d39bceb7bcf00c2909ad29c1d91ed3b'




